"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var Subject_1 = require("rxjs/Subject");
var forms_1 = require("@angular/forms");
require("rxjs/add/operator/skipWhile");
require("rxjs/add/operator/do");
var core_2 = require("@ui-model/core");
var common_1 = require("@ui-model/common");
var TYPE_AHEAD_ACCESSOR = {
    provide: forms_1.NG_VALUE_ACCESSOR,
    useExisting: core_1.forwardRef(function () { return TypeAheadComponent; }),
    multi: true,
};
var TypeAheadComponent = (function () {
    function TypeAheadComponent() {
        this.dropDown = new core_2.Toggle();
        this.checker = new Subject_1.Subject();
        this.displayField = 'name';
        this.placeholder = '-';
        this.formatter = this.defaultFormatter.bind(this);
        this.parser = this.defaultParser.bind(this);
        this.search = new core_1.EventEmitter();
        this.term = '';
        this.disabled = false;
    }
    TypeAheadComponent.prototype.defaultFormatter = function (value) {
        if (!value) {
            return '';
        }
        if (value.hasOwnProperty('format') && common_1.isFunction(value.format)) {
            return value.format();
        }
        else {
            return value[this.displayField];
        }
    };
    ;
    TypeAheadComponent.prototype.defaultParser = function (value) {
        if (!value) {
            return '';
        }
        if (value.hasOwnProperty('parse') && common_1.isFunction(value.format)) {
            return value.parse();
        }
        else {
            return value[this.displayField];
        }
    };
    TypeAheadComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.sub = this.checker.asObservable()
            .skipWhile(function (term) { return !term; })
            .debounceTime(200)
            .do(function () {
            _this.search.emit(_this.term);
        })
            .subscribe(function () {
            _this.dropDown.open();
        });
    };
    TypeAheadComponent.prototype.ngOnDestroy = function () {
        this.checker.complete();
        this.sub.unsubscribe();
    };
    Object.defineProperty(TypeAheadComponent.prototype, "value", {
        get: function () {
            return this._value;
        },
        set: function (value) {
            this._value = value;
            this.term = value && this.parser(value);
        },
        enumerable: true,
        configurable: true
    });
    TypeAheadComponent.prototype.changed = function () {
        if (this._change) {
            this._change(this.value);
        }
    };
    TypeAheadComponent.prototype.writeValue = function (value) {
        this.value = value;
    };
    TypeAheadComponent.prototype.registerOnChange = function (fn) {
        this._change = fn;
    };
    TypeAheadComponent.prototype.registerOnTouched = function (fn) {
        this._touched = fn;
    };
    TypeAheadComponent.prototype.setDisabledState = function (isDisabled) {
        this.disabled = isDisabled;
    };
    TypeAheadComponent.prototype.select = function (item) {
        this.value = item;
        this.changed();
    };
    TypeAheadComponent.prototype.clear = function () {
        this.select(undefined);
    };
    TypeAheadComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'ui-type-ahead',
                    templateUrl: './type-ahead.component.html',
                    styleUrls: ['./type-ahead.component.scss'],
                    providers: [TYPE_AHEAD_ACCESSOR],
                },] },
    ];
    /** @nocollapse */
    TypeAheadComponent.ctorParameters = function () { return []; };
    TypeAheadComponent.propDecorators = {
        "items": [{ type: core_1.Input },],
        "displayField": [{ type: core_1.Input },],
        "placeholder": [{ type: core_1.Input },],
        "formatter": [{ type: core_1.Input },],
        "parser": [{ type: core_1.Input },],
        "search": [{ type: core_1.Output },],
        "disabled": [{ type: core_1.Input },],
    };
    return TypeAheadComponent;
}());
exports.TypeAheadComponent = TypeAheadComponent;
//# sourceMappingURL=type-ahead.component.js.map